@@ -588,7 +588,7 @@ class BipartiteLongBase(bpd.BipartiteBase):
             }
             articulation_params_dict = {
                 'observation': {'G': G2, 'max_j': max_j2, 'is_sorted': True},
-                'spell': {'G': G2, 'max_j': max_j2, 'is_sorted': True, 'copy': False},
+                'spell': {'G': G2, 'max_j': max_j2, 'is_sorted': True},
                 'match': {'G': G2, 'max_j': max_j2}
             }
             articulation_rows = articulation_fn_dict[leave_out_group](**articulation_params_dict[leave_out_group])
@@ -596,7 +596,7 @@ class BipartiteLongBase(bpd.BipartiteBase):
             if len(articulation_rows) > 0:
                 # If new frame is not leave-one-(observation/spell/match)-out connected, recompute connected components after dropping articulation rows (but note that articulation rows should be kept in the final dataframe) (NOTE: this does not require a copy)
                 G2, max_j3 = frame_cc.drop_rows(articulation_rows, drop_returns_to_stays, is_sorted=True, reset_index=False, copy=False)._construct_graph(f'leave_out_{leave_out_group}', is_sorted=True, copy=False)
-                cc_list_2 = G2.components()
+                cc_list_2 = G2.components(mode='weak')
                 if len(cc_list_2) > 1:
                     # Recursion step (only necessary if dropping articulation workers disconnects the set of firms)
                     frame_cc = frame_cc._leave_out_observation_spell_match(cc_list=cc_list_2, max_j=max_j3, leave_out_group=leave_out_group, component_size_variable=component_size_variable, drop_returns_to_stays=drop_returns_to_stays, frame_largest_cc=frame_largest_cc, is_sorted=True, copy=False, first_loop=False)
@@ -696,7 +696,7 @@ class BipartiteLongBase(bpd.BipartiteBase):
             if len(articulation_workers) > 0:
                 # If new frame is not leave-one-worker-out connected, recompute connected components after dropping articulation workers (but note that articulation workers should be kept in the final dataframe) (NOTE: this does not require a copy)
                 G2, max_j3 = frame_cc.drop_ids('i', articulation_workers, drop_returns_to_stays, is_sorted=True, reset_index=False, copy=False)._construct_graph('leave_out_worker', is_sorted=True, copy=False)
-                cc_list_2 = G2.components()
+                cc_list_2 = G2.components(mode='weak')
                 if len(cc_list_2) > 1:
                     # Recursion step (only necessary if dropping articulation workers disconnects the set of firms)
                     frame_cc = frame_cc._leave_out_worker(cc_list=cc_list_2, max_j=max_j3, component_size_variable=component_size_variable, drop_returns_to_stays=drop_returns_to_stays, frame_largest_cc=frame_largest_cc, is_sorted=True, copy=False, first_loop=False)
